2 ms·
First off, I'm really no expert in Python or optimizations - I'm only reporting on observations. Having said that, I was pretty surprised that the list compreh
by edanm 16y ago
First off, I'm really no expert in Python or optimizations - I'm only reporting on observations.
Having said that, I was pretty surprised that the list comprehensions ran faster than map, exactly because of point 2 - I had assumed that map used a c-loop, whereas list comprehensions did not. Unfortunately, I don't have that code sitting around anywhere so I can't redo the tests - I just remember being very surprised by those results.
- deathflute 16y agoIn my experience edanm is correct. map/reduce/filter are faster with built-in functions, but list comprehensions are faster with user-defined ones For eg. using python 2.5.2 In [9]: l = ['10'] * 5000000 In [10]: timeit -n5 map(int, l) 5 loops, best of 3: 1.29 s per loop In [11]: timeit -n5 [int(i) for i in l] 5 loops, best of 3: 1.64 s per loop
- devinj 16y agoYou mean "incorrect". Also, I did post detailed timing results above.